@@ -5,10 +5,10 @@ package Acme::CPANModulesBundle::PERLANCAR;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-01'; # DATE
 our $DIST = 'Acme-CPANModulesBundle-PERLANCAR'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 1;
-# ABSTRACT: Lists of Acme::CPANModules::PERLANCAR::* modules
+# ABSTRACT: Bundle of Acme::CPANModules::PERLANCAR::* modules
 
 __END__
 
@@ -18,11 +18,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModulesBundle::PERLANCAR - Lists of Acme::CPANModules::PERLANCAR::* modules
+Acme::CPANModulesBundle::PERLANCAR - Bundle of Acme::CPANModules::PERLANCAR::* modules
 
 =head1 VERSION
 
-This document describes version 0.011 of Acme::CPANModulesBundle::PERLANCAR (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.
+This document describes version 0.012 of Acme::CPANModulesBundle::PERLANCAR (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.
 
 =head1 DESCRIPTION
 
@@ -45,6 +45,10 @@ during building, your distribution does not specify a prerequisite to any of the
 modules listed here. (You should make your own blacklist though).
 
 
+=item * L<PERLANCAR::MyCLIWithSubcommands|Acme::CPANModules::PERLANCAR::MyCLIWithSubcommands>
+
+List of distributions that contain CLI scripts with subcommands.
+
 =item * L<PERLANCAR::MyGetoptLongExperiment|Acme::CPANModules::PERLANCAR::MyGetoptLongExperiment>
 
 List of my experiments writing Getopt::Long replacementsE<sol>alternatives.
@@ -53,7 +57,7 @@ Most of these modules provide a L<Getopt::Long>-compatible interface, but they
 differ in some aspect: either they offer more features (or less).
 
 
-=item * L<PERLANCAR::Retired|Acme::CPANModules::PERLANCAR::Retired>
+=item * L<PERLANCAR::MyRetired|Acme::CPANModules::PERLANCAR::MyRetired>
 
 List of my retired modules.
 
